aboutsummaryrefslogtreecommitdiff
path: root/lib/Transforms/Utils/BasicBlockUtils.cpp
diff options
context:
space:
mode:
authorBob Wilson <bob.wilson@apple.com>2010-02-16 21:06:42 +0000
committerBob Wilson <bob.wilson@apple.com>2010-02-16 21:06:42 +0000
commitae23daf63afccd68be965ff4f7acafa818d76aaa (patch)
treec1f91de79651bec86e58a778ebe73c34bf671ef9 /lib/Transforms/Utils/BasicBlockUtils.cpp
parent8939b0d8a930729cd8d9c06dd4afd08de93260d2 (diff)
Rename SuccessorNumber to GetSuccessorNumber.
git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@96387 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Transforms/Utils/BasicBlockUtils.cpp')
-rw-r--r--lib/Transforms/Utils/BasicBlockUtils.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/lib/Transforms/Utils/BasicBlockUtils.cpp b/lib/Transforms/Utils/BasicBlockUtils.cpp
index 60185d2687..1f62dabb20 100644
--- a/lib/Transforms/Utils/BasicBlockUtils.cpp
+++ b/lib/Transforms/Utils/BasicBlockUtils.cpp
@@ -274,10 +274,11 @@ void llvm::RemoveSuccessor(TerminatorInst *TI, unsigned SuccNum) {
ReplaceInstWithInst(TI, NewTI);
}
-/// SuccessorNumber - Search for the specified successor of basic block BB and
-/// return its position in the terminator instruction's list of successors.
-/// It is an error to call this with a block that is not a successor.
-unsigned llvm::SuccessorNumber(BasicBlock *BB, BasicBlock *Succ) {
+/// GetSuccessorNumber - Search for the specified successor of basic block BB
+/// and return its position in the terminator instruction's list of
+/// successors. It is an error to call this with a block that is not a
+/// successor.
+unsigned llvm::GetSuccessorNumber(BasicBlock *BB, BasicBlock *Succ) {
TerminatorInst *Term = BB->getTerminator();
#ifndef NDEBUG
unsigned e = Term->getNumSuccessors();
@@ -293,7 +294,7 @@ unsigned llvm::SuccessorNumber(BasicBlock *BB, BasicBlock *Succ) {
/// SplitEdge - Split the edge connecting specified block. Pass P must
/// not be NULL.
BasicBlock *llvm::SplitEdge(BasicBlock *BB, BasicBlock *Succ, Pass *P) {
- unsigned SuccNum = SuccessorNumber(BB, Succ);
+ unsigned SuccNum = GetSuccessorNumber(BB, Succ);
// If this is a critical edge, let SplitCriticalEdge do it.
TerminatorInst *LatchTerm = BB->getTerminator();